# Source Files for the RNBIP Emulator
# Alpha Release
```bash
pip install rnbip-paulgeorge==0.1.0
```
## Extention project ideas
#### COCO-TB Verilator Co Simulation Setup
#### Emulator to Nexys 4 Fpga Project One Click Build instrumentation
#### Web Based emulator
#### Create an LLVM Backend for RNBIP 8/16

Please Contact: Prof. R.N.Biswas or Paul George (command.paul@gmail.com) , Vedant Chakravarty and Prasanna Natarajan for more information.

